/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: categorywidget.h 334 2005-11-07 19:28:00Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AQBANKING_KDE_CATEGORYWIDGET_H
#define AQBANKING_KDE_CATEGORYWIDGET_H


#include "categorywidget.ui.h"

#include <gwenhywfar/db.h>

class KBanking;


class CategoryWidget : public CategoryWidgetUi {
  Q_OBJECT
public:
  CategoryWidget(QWidget* parent=0,
                 const char* name=0,
                 WFlags fl=0);
  virtual ~CategoryWidget();

  void init(KBanking *kb);

  void updateList();
  void rebuildList();

public slots:
  void slotNew();
  void slotEdit();
  void slotDelete();

private:
  KBanking *_app;

};





#endif
